@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package Data::Semantic::Net;
-our $VERSION = '1.100850';
+BEGIN {
+  $Data::Semantic::Net::VERSION = '1.101610';
+}
 # ABSTRACT: Semantic data classes for net-related data
 use parent qw(Data::Semantic);
 1;
@@ -18,7 +20,7 @@ Data::Semantic::Net - Semantic data classes for net-related data
 
 =head1 VERSION
 
-version 1.100850
+version 1.101610
 
 =head1 DESCRIPTION
 
@@ -46,7 +48,7 @@ See perlmodinstall for information and options on installing Perl modules.
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Data-Semantic-Net>.
+L<http://rt.cpan.org>.
 
 =head1 AVAILABILITY
 
